California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 058 - SB 1174 (CHAPTER 753, STATUTES OF 2014), LARA. ENGLISH LANGUAGE EDUCATION View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1374153 | LARA BALLOT MEASURE COMMITTEE; CALIFORNIANS FOR A 21ST CENTURY ECONOMY - YES ON 58, A RICARDO | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1391170 | MILLION VOTER PROJECT ACTION FUND - YES ON 55, 56, 57, 58, 62, AND NO ON 66, SPONSORED BY SOCIAL JUSTICE ADVOCATES AND ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1386477 | YES ON 58, CALIFORNIANS FOR ENGLISH PROFICIENCY SPONSORED BY TEACHERS AND SERVICE EMPLOYEES ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
931704 | UNITED TEACHERS LOS ANGELES-POLITICAL ACTION COUNCIL OF EDUCATORS (PACE) ISSUES, A COMMITTEE FOR PROPOSITIONS 55 AND 58 | SUPPORT